==> calamares-settings-solydxk_4.17%2Br13.tar.xz: source/ts/calamares-solydxk_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Благодарим Вас за выбор SolydX&lt;/h3&gt;&lt;br /&gt;Вы выбрали дистрибутив Linux, который:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Безопасный и стабильный&lt;/li&gt;&lt;li&gt;Быстрый и отзывчивый&lt;/li&gt;&lt;li&gt;Готов к использованию&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Наслаждайтесь этим новым релизом и спасибо, что выбрали SolydXK.&lt;br /&gt;&lt;br /&gt;Установка занимает 15-30 минут, в зависимости от настроек.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Стоя на плечах Гиганта&lt;/h3&gt;&lt;br /&gt;SolydXK это дистрибутив на базе Debian GNU/Linux и полностью с ним совместимый.&lt;br /&gt;&lt;br /&gt;SolydXK использует легковесный рабочий стол xfce для SolydX или настраиваемый и невероятно мощный рабочий стол KDE для SolydK.&lt;br /&gt;&lt;br /&gt;Наши инновации, стремительное развитие Debian и огромного количество пакетов - делает SolydXK одним из наиболее привлекательных настольных операционных систем, доступных для домашних пользователей.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Из коробки&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird и LibreOffice уже предустановлены в SolydXK, так что вы можете сразу начать работу.&lt;br /&gt;&lt;br /&gt;В отличие от других дистрибутивов Linux, SolydXK уже готов воспроизводить мультимедиа без необходимости установки дополнительных кодеков.&lt;br /&gt;&lt;br /&gt;Широкий выбор программного обеспечения можно установить с помощью щелчка мыши.&lt;br /&gt;&lt;br /&gt;SolydXK совместим с большинством популярных форматов файлов, такие как: zip, doc, xls, pdf, rar, mp3, wmv, mpg, mp4, mov и многими другими.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Офисные инструменты готовы к использованию сразу после установки SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, мощный набор офисного программного обеспечения, сразу поставляется с SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice  очень прост в освоении и использовании.&lt;br /&gt;&lt;br /&gt;YВы можете использовать его для создания писем, презентаций и электронных таблиц, а также диаграмм и баз данных.&lt;br /&gt;&lt;br /&gt;LibreOffice использует стандарт OpenDocument, а так же он работает с документами других популярных офисных пакетов, включая WordPerfect и Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Альтернатива основным операционным системам&lt;/h3&gt;&lt;br /&gt;SolydXK прост в использовании, но при этом мощный и настраиваемый.&lt;br /&gt;&lt;br /&gt;SolydXK это безопасная  и стабильная операционная система. В отличие от других операционных систем, она не подвержена компьютерным вирусам или программам-шпионам, не страдает от фрагментации диска, и в ней отсутствует реестр, который требует периодической очистки.&lt;br /&gt;&lt;br /&gt;SolydXK может обнаружить другие операционные системы, и установить себя рядом с ними. Вы можете выбрать какую операционную систему запускать при запуске компьютера.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Безопасные обновления&lt;/h3&gt;&lt;br /&gt;В некоторых операционных системах сделать Обновление системы сложнее, чем на самом деле должно быть. В SolydXK обновления проходят легко и быстро.&lt;br /&gt;&lt;br /&gt;Менеджер обновлений располагается в системном трее и оповещает вас об обновлениях. Вы можете не применять их, если не хотите. Менеджер обновлений не будет надоедать Вам всплывающими подсказками.&lt;br /&gt;&lt;br /&gt;Все обновления внимательно проверяются доверенными разработчиками и мейнтейнерами.&lt;br /&gt;&lt;br /&gt;Все файлы хранятся в специальных безопасных хранилищах и перед использованием проходят процедуру аутентификации.&lt;br /&gt;&lt;br /&gt;Репозитории с обновлениями безопасности синхронизируется ежедневно.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Большое сообщество&lt;/h3&gt;&lt;br /&gt;Пользователи SolydXK всегда готовы прийти на помощь. Не стесняйтесь задавать вопросы на нашем форуме и принимать участие в жизни сообщества.&lt;br /&gt;&lt;br /&gt;Присылайте нам свои отзывы и делитесь с нами своим опытом. Мы рассмотрим ваши идеи и попробуем воплотить их в жизнь, чтобы улучшить SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Благодарим Вас за выбор SolydX&lt;/h3&gt;&lt;br /&gt;Вы выбрали дистрибутив Linux, который:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Безопасный и стабильный&lt;/li&gt;&lt;li&gt;Быстрый и отзывчивый&lt;/li&gt;&lt;li&gt;Готов к использованию&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Наслаждайтесь этим новым релизом и спасибо, что выбрали SolydXK.&lt;br /&gt;&lt;br /&gt;Установка занимает 15-30 минут, в зависимости от настроек.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Стоя на плечах Гиганта&lt;/h3&gt;&lt;br /&gt;SolydXK это дистрибутив на базе Debian GNU/Linux и полностью с ним совместимый.&lt;br /&gt;&lt;br /&gt;SolydXK использует легковесный рабочий стол xfce для SolydX или настраиваемый и невероятно мощный рабочий стол KDE для SolydK.&lt;br /&gt;&lt;br /&gt;Наши инновации, стремительное развитие Debian и огромного количество пакетов - делает SolydXK одним из наиболее привлекательных настольных операционных систем, доступных для домашних пользователей.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Из коробки&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird и LibreOffice уже предустановлены в SolydXK, так что вы можете сразу начать работу.&lt;br /&gt;&lt;br /&gt;В отличие от других дистрибутивов Linux, SolydXK уже готов воспроизводить мультимедиа без необходимости установки дополнительных кодеков.&lt;br /&gt;&lt;br /&gt;Широкий выбор программного обеспечения можно установить с помощью щелчка мыши.&lt;br /&gt;&lt;br /&gt;SolydXK совместим с большинством популярных форматов файлов, такие как: zip, doc, xls, pdf, rar, mp3, wmv, mpg, mp4, mov и многими другими.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Офисные инструменты готовы к использованию сразу после установки SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, мощный набор офисного программного обеспечения, сразу поставляется с SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice  очень прост в освоении и использовании.&lt;br /&gt;&lt;br /&gt;YВы можете использовать его для создания писем, презентаций и электронных таблиц, а также диаграмм и баз данных.&lt;br /&gt;&lt;br /&gt;LibreOffice использует стандарт OpenDocument, а так же он работает с документами других популярных офисных пакетов, включая WordPerfect и Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Альтернатива основным операционным системам&lt;/h3&gt;&lt;br /&gt;SolydXK прост в использовании, но при этом мощный и настраиваемый.&lt;br /&gt;&lt;br /&gt;SolydXK это безопасная  и стабильная операционная система. В отличие от других операционных систем, она не подвержена компьютерным вирусам или программам-шпионам, не страдает от фрагментации диска, и в ней отсутствует реестр, который требует периодической очистки.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Безопасные обновления&lt;/h3&gt;&lt;br /&gt;В некоторых операционных системах сделать Обновление системы сложнее, чем на самом деле должно быть. В SolydXK обновления проходят легко и быстро.&lt;br /&gt;&lt;br /&gt;Менеджер обновлений располагается в системном трее и оповещает вас об обновлениях. Вы можете не применять их, если не хотите. Менеджер обновлений не будет надоедать Вам всплывающими подсказками.&lt;br /&gt;&lt;br /&gt;Все обновления внимательно проверяются доверенными разработчиками и мейнтейнерами.&lt;br /&gt;&lt;br /&gt;Все файлы хранятся в специальных безопасных хранилищах и перед использованием проходят процедуру аутентификации.&lt;br /&gt;&lt;br /&gt;Репозитории с обновлениями безопасности синхронизируется ежедневно.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Большое сообщество&lt;/h3&gt;&lt;br /&gt;Пользователи SolydXK всегда готовы прийти на помощь. Не стесняйтесь задавать вопросы на нашем форуме и принимать участие в жизни сообщества.&lt;br /&gt;&lt;br /&gt;Присылайте нам свои отзывы и делитесь с нами своим опытом. Мы рассмотрим ваши идеи и попробуем воплотить их в жизнь, чтобы улучшить SolydXK.</translation>
    </message>
</context>
</TS>
